#!/usr/bin/env python
import sys
import os
from csr_ha.client_api import ha_api
from csr_cloud.csr_cloud import csr_cloud as cloud
import argparse
import json

def validate_params(c, args):

    if args.i != "all":
        try:
            if int(args.i) < 1 or int(args.i) > 1023:
                print "400: Node_index -i expected to be in range <1-1023>/<all> node"
                c.log.error("400: Node_index -i expected to be in range <1-1023>/<all> node")
                sys.exit()
        except (ValueError, TypeError) as e:
            print "400: Node_index -i expected to be in range <1-1023>/<all> node"
            c.log.error("400: Node_index -i expected to be in range <1-1023>/<all> node")
            sys.exit()
    else:
        if args.e == "peerFail":
            print "400: Cannot perform peerFail node_event for all nodes"
            sys.exit()
        #Internally processing all as Nodeindex 0
        args.i = 0
        if args.mi:
            print "400: Unnecessary -mi parameter when using <all> as node_index"


def main(argv):
    c = cloud('HA')

    parser = argparse.ArgumentParser(description="CSR HA Create Node")
    parser._action_groups.pop()
    required = parser.add_argument_group('required arguments')
    optional = parser.add_argument_group('optional arguments')
    
    required.add_argument('-i', nargs='?',help='<nodeIndex>', required=True)
    optional.add_argument('-mi', nargs='?',help='<maxIndex>', type=int, default=None, required=False)
    required.add_argument('-e', help='<eventType>  {peerFail | revert | verify}', choices=['peerFail', 'revert', 'verify'], default=None, required=True)

    args = parser.parse_args()

    # Validate the cloud agnostic parameters
    validate_params(c, args)
    sys.argv[0] = os.path.basename(__file__)
    cmd_string = ' '.join(sys.argv)

    req_msg = ha_api.send_command_to_server(c, cmd_string)
    if req_msg == 'OK':
        rsp_msg = json.loads(ha_api.get_response_from_server(c))
        if rsp_msg['code'] == 200 or rsp_msg['code'] == 199:
            c.log.info("Client: node_event: received OK from server")
            if 'msg' in rsp_msg:
                print("{}: {}".format(rsp_msg['code'], rsp_msg['msg']))
            return 0
        else:
            c.log.error("Bad response: %s" % rsp_msg)
            print "400: Unable to process node_event"
            return 7
    else:
        print req_msg

if __name__ == '__main__':
    sys.exit(main(sys.argv))

  





#
# Recursively validates all python files with pyflakes that were modified
# since the last validation, and provides basic stats. Ignores hidden
# directories.
#
# NOTE:
# You should set your favourite version control system to ignore
# the validate.db file that is used to track when which files
# have changed since last validation.
#
# Usage: $ python validate.py [--help] [--all] [--stats]
#

try:
    import pyflakes
    pyflakes # avoid unused warning when validating self!
except ImportError:
    print 'Validate requires pyflakes. Please install '\
          'with: pip install pyflakes'
    exit()

import argparse
import os
import pickle
from subprocess import call
import re

# Matches:       .dir/foo   /foo/.git/bar
# Doesn't match: ./dir/foo  ./foo/./bar
path_in_hidden_folders = re.compile(r'^(.*/)?\.[^/]+/.+$')

# Options
parser = argparse.ArgumentParser(description='Recursively validates all '
    'python files with pyflakes that were modified since the last '
    'validation,and provides basic stats. Ignores hidden directories.')
parser.add_argument('--all', dest='all', action='store_true', default=False,
                    help='check all files, regardless of last modification '
                         'and validation dates')
parser.add_argument('--stats', dest='stats', action='store_true',
                    default=False, help='return statistics on Python '
                                        'files (line count, etc)')
args = parser.parse_args()

# Setup
skip_paths = []

# Stats
file_count = 0
validated_count = 0
validated_issue_count = 0
line_count = 0

# Validate db
try:
    db_file = open('./validate.db', 'r+b')
    validate_db = pickle.load(db_file)
except (EOFError, IOError):
    db_file = open('./validate.db', 'w+b')
    validate_db = {'modifieds': {}}

# Validate recursively - traverse all files and folders
if args.all or not validate_db['modifieds']:
    print '\n---- Validating all files ----'
else:
    print '\n---- Validating files modified since last validation ----'
for dirname, dirnames, filenames in os.walk('.'):
    for filename in filenames:
        if filename.endswith('.py'):

            # File details
            path = os.path.join(dirname, filename)

            # Skip
            if path in skip_paths:
                continue
            if path_in_hidden_folders.match(path):
                continue

            # Validate
            file_count += 1
            mtime = int(os.stat(path).st_mtime)
            if args.all or validate_db['modifieds'].get(path, 0) < mtime:
                if call(['pyflakes', path]):
                    validated_issue_count += 1
                validated_count += 1
            if not args.all:
                validate_db['modifieds'][path] = mtime

            # Stats
            if args.stats:
                line_count += sum(1 for line in open(path))
if validated_issue_count == 0:
    print 'ALL OKAY'
print '\n---- Validation summary ----'
print 'Files with validation issues: %i' % validated_issue_count
print 'Validated files: %i' % validated_count
print 'Total python files: %i' % file_count

# Print stats
if args.stats:
    print '\n---- Stats ----'
    print 'Total python line count: %i' % line_count

# Save db
db_file.seek(0)
pickle.dump(validate_db, db_file, pickle.HIGHEST_PROTOCOL)
db_file.close()

# Finish
print ''



#!/usr/bin/env python
import sys
import socket
from csr_ha.server import ha_server
from csr_cloud.csr_cloud import csr_cloud as cloud
import argparse
import time
import json
from os.path import expanduser

sock_file = expanduser("~") +"/cloud/HA/sock_file"

def send_command_to_server(c, command):
    global sock
    Max_Sock_Attempts = 4
    c.log.info("Sending %s" % command)

    # Create a UDS socket and connect the socket to the port where
    # the server is listening
    for attempt in range(Max_Sock_Attempts):
        try:
            sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
            sock.connect(sock_file)
            sock.sendall(command)
            sock.shutdown(socket.SHUT_WR)
            return 'OK'
        except Exception as e:
            c.log.exception("API: Socket Exception %s " % e)
            pass
        c.log.error("API: attempt %d Failed.  Retrying" % (attempt+1))
        time.sleep(2)
    else:
        c.log.error("Unable to connect to server")
        return "%s failed" % command


def get_response_from_server(c):
    try:
        sock_buf_size = 255
        response = ""
        while True:
            rsp_msg = sock.recv(sock_buf_size)
            if len(rsp_msg) < sock_buf_size:
               response = response + rsp_msg
               sock.close()
               return response
            response = response + rsp_msg
    except Exception as err:
       c.log.exception("API: Socket Exception %s" % err)
       c.log.error("API: Unable to receive response from HA server")
       # returning the error as a dict (converted to string) to be consistent with response when there is no exception
       # it also makes retrieving the error response easier in create_node.py to display to customers
       error_response = {}
       error_response['code'] = 400
       error_response['msg'] = "API: Socket Exception %s" % err
       response = json.dumps(error_response)
       return response
    
    
def main(argv):
    c = cloud('HA')

    parser = argparse.ArgumentParser(description="CSR HA API Server")
    parser.add_argument('-c', nargs='?',help='{start | stop | ping}', default=None)
    args = parser.parse_args()

    action = args.c
    if action == 'start':
        ha_server.start_server(c)
        return 0
    elif action == 'stop':
        cmd_string = 'stop'
    elif action == 'ping':
        cmd_string = 'ping'

    req_msg = send_command_to_server(c, cmd_string)
    if req_msg == 'OK':
        rsp_msg = get_response_from_server(c)
        if 'OK' == rsp_msg:
            return 0
        else:
            c.log.error("Bad response: %s" % rsp_msg)
            return 4
    else:
        c.log.error("Req_msg: %s" % req_msg)
        print(req_msg)

if __name__ == '__main__':
    sys.exit(main(sys.argv))
  





#!/usr/bin/env python
import sys
import os
from csr_ha.client_api import ha_api
from csr_cloud.csr_cloud import csr_cloud as cloud
import argparse
import json

def validate_params(c, args):
    if args.i == 0:
        c.log.error("Client: clear_node: route index of zero is reserved")
        return 2

    try:
        if int (args.i) < 1 or int(args.i) > 1023:
            print "400: Node_index -i expected to be in range <1-1023>"
            sys.exit()
    except (ValueError, TypeError) as e:
        print "400: Node_index -i expected to be in range <1-1023>"
        sys.exit()

def main(argv):
    c = cloud('HA')
    parser = argparse.ArgumentParser(description="CSR HA Clear Node")
    parser._action_groups.pop()
    required = parser.add_argument_group('required arguments')
    optional = parser.add_argument_group('optional arguments')
    required.add_argument('-i', nargs='?', help='nodeIndex', required=True)
    optional.add_argument('-m', help='to clear the mode', default=None, action="store_true")

    c.ha.clear_param_parser(optional, required)
    args = parser.parse_args()
    argc = len(argv)

    if (argc != 2) and (argc < 4):
        c.log.error("Client: clear_params: invalid number of arguments %d" % argc)
        print "400: Invalid number of arguments %d" % argc
        parser.print_help()
        parser.exit()

    # Validate the cloud agnostic parameters
    validate_params(c, args)


    sys.argv[0] = os.path.basename(__file__)
    cmd_string = ' '.join(sys.argv)

    req_msg = ha_api.send_command_to_server(c, cmd_string)

    if req_msg == 'OK':
        rsp_msg = json.loads(ha_api.get_response_from_server(c))
        if rsp_msg['code'] == 200 or rsp_msg['code'] == 199:
            c.log.info("Client: clear_params: received OK from server")
            if "msg" in rsp_msg:
                print "{}: {}".format(rsp_msg['code'], rsp_msg['msg'])
            return 0
        else:
            c.log.error("Bad response: %s" % rsp_msg)
            if "msg" in rsp_msg:
                print "{}: {}".format(rsp_msg['code'], rsp_msg['msg'])
            return 3
    else:
        c.log.error("Req_msg: %s" % req_msg)
        print(req_msg)
        return 3

if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
import sys
import os
from csr_ha.client_api import ha_api
from csr_cloud.csr_cloud import csr_cloud as cloud
import argparse
import ipaddress
import json

def validate_params(c, args):

    try:
        if int(args.i) < 1 or int(args.i) > 1023:
            print "400: Node_index -i expected to be in range <1-1023>"
            sys.exit()
    except ValueError as e:
        print "400: Node_index -i expected to be in range <1-1023>"
        sys.exit()

    if args.r:
        try:
            ipaddress.ip_network(unicode(args.r))
            if "/" not in args.r:
                raise ValueError
        except (TypeError, ValueError) as e:
            print ("400: Route(-r) %s is not in correct IPv4/IPv6 network format " % args.r)
            c.log.error(
                "Route (-r) {} is not in the right IPv4/IPv6 network format while setting node: {}".format(args.r,
                                                                                                           args.i))
            sys.exit()

    if args.n:
        nextHopValidation = c.ha.validate_nexthop(args.n)
        if nextHopValidation:
            print ("400: Nexthop(-n) %s is not in right IPv4/IPv6 address format " % args.n)
            c.log.error(
                "Nexthop(-n) {} is not in right IPv4/IPv6 address format while setting node: {}".format(args.n, args.i))
            sys.exit()

def main(argv):
    c = cloud('HA')

    parser = argparse.ArgumentParser(description="CSR HA Set Node")
    parser._action_groups.pop()
    required = parser.add_argument_group('required arguments')
    optional = parser.add_argument_group('optional arguments')

    required.add_argument('-i', nargs='?', help='<nodeIndex>', required=True)
    optional.add_argument('-m', help='<mode> {primary | secondary}', default=None, choices=['primary', 'secondary'])

    c.ha.set_node_parser(optional, required)
    args = parser.parse_args()

    # Validate the cloud agnostic parameters
    validate_params(c, args)

    sys.argv[0] = os.path.basename(__file__)
    cmd_string = ' '.join(sys.argv)

    req_msg = ha_api.send_command_to_server(c, cmd_string)
    if req_msg == 'OK':
        rsp_msg = json.loads(ha_api.get_response_from_server(c))
        if rsp_msg['code'] == 200 or rsp_msg['code'] == 199:
            c.log.info("Client: set_params: received OK from server")
            if 'msg' in rsp_msg:
                print("{}: {}".format(rsp_msg['code'], rsp_msg['msg']))
                print "200: Set_params processed successfully"
            return 0
        else:
            c.log.error("Bad response: %s" % rsp_msg)
            print("400: Unable to set parameters for node: %s" % args.i)
            if 'msg' in rsp_msg:
                print("{}: {}".format(rsp_msg['code'], rsp_msg['msg']))
                print "400: Unable to process set_params"
            return 3
    else:
        print req_msg

if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
import sys
import os
import ha_api
import argparse
from csr_cloud.csr_cloud import csr_cloud as cloud
import textwrap
import json


def validate_params(c, args):

    if args.i != "all":
        try:
            if int(args.i) < 1 or int(args.i) > 1023:
                print "400: Node_index -i expected to be in range <1-1023>/<all> show all nodes"
                sys.exit()
        except (TypeError, ValueError) as e:
            print "400: Node_index -i expected to be in range <1-1023>/<all> show all nodes"
            sys.exit()


def main(argv):
    c = cloud('HA')
    parser = argparse.ArgumentParser(description="CSR HA Show Node", formatter_class=argparse.RawTextHelpFormatter)
    parser._action_groups.pop()
    required = parser.add_argument_group('optional arguments')

    required.add_argument('-i', default="all",required = True, help=textwrap.dedent('''\
    <1..1023>      nodeIndex
    <all>         show all nodes
    '''))

    args = parser.parse_args()

    # Validate the cloud agnostic parameters
    validate_params(c, args)

    sys.argv[0] = os.path.basename(__file__)
    cmd_string = ' '.join(sys.argv)

    req_msg = ha_api.send_command_to_server(c, cmd_string)
    if req_msg == 'OK':
        rsp_msg = json.loads(ha_api.get_response_from_server(c))
        if rsp_msg['code'] == 200 or rsp_msg['code'] == 199:
            c.log.info("Client: show_node: received OK from server")
            print "{}: Retrieved the node successfully \n{}".format(rsp_msg['code'], rsp_msg['msg'])

        elif  rsp_msg['code'] == 400:
            c.log.info("Client: show_node: No redundancy nodes found")
            print "{}: {}".format(rsp_msg['code'], rsp_msg['msg'])
        else:
            c.log.info("Client: show_node: received ERR from server")
            print "400: Received ERR from server"
    else:
        c.log.error("Req_msg: %s" % req_msg)
        return 3

if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
import os
import sys
import socket
from multiprocessing import Process
from node_mgr import NodeTable
from csr_ha.server import event_mgr
from csr_cloud.csr_cloud import csr_cloud as cloud
import argparse
from os.path import expanduser
import json

server_running = False
home = expanduser("~")
sock_file = home + "/cloud/HA/sock_file"
node_file = home + "/cloud/HA/node_file"


def info(title):
    print(title)
    print('module name:', __name__)
    print('parent process:', os.getppid())
    print('process id:', os.getpid())


def create_node(c, table, params):
    c.log.info("Processing a create_node command")
    c.log.info("Dict of parameters is %s" % params)
    return table.create_node(params)


def set_params(c, table, params):
    c.log.info("Processing a set_param command")
    c.log.info("Dict of parameters is %s" % params)
    return table.set_params(params)


def clear_params(c, table, params):
    c.log.info("Processing a clear_param command")
    c.log.info("Dict of parameters is %s" % params)
    return table.clear_params(params)


def show_node(c, table, params):
    if params['index'] == 'all':
        total_str = table.show_table()
        c.log.info("See output on server")
        return total_str
    else:
        node_desc = table.show_node(params)
        return node_desc


def delete_node(c, table, params):
    c.log.info("Processing a delete_node command")
    c.log.info("Dict of parameters is %s" % params)
    return table.delete_node(params)


def event_on_one_node(c, event_type, node, params):
    event_mgr.handle_event(node, event_type)


def node_event(c, table, params):
    response = {}
    response['msg'] = ""
    response['code'] = 200
    if params['index'] == 'all':
        index = 0
    else:
        index = int(params['index'])

    # Return if none of the nodes are configured to be primary
    process_event = False
    if params['event'] == "revert":
        for node in table.nodes:
            if node.has_key('mode') :
                if node['mode'] == 'primary':
                    process_event = True

        if not process_event and not c.ha.do_revert():
            c.log.info("No primary nodes configured, revert event aborted")
            response['msg'] = "No primary nodes configured, revert event aborted"
            return json.dumps(response)

    max_node = 0
    if 'range' in params:
        max_node = int(params['range'])
    event_type = params['event']

    for node in table.nodes:
        process_node = False
        node_index = int(node['index'])
        if (((index > 0) and (max_node == 0)) or (index == max_node)):
            # Looking to match a single node
            if node_index == index or index == 0:
                process_node = True
            # Do not process node
            if node.has_key('mode'):
                 if node['mode'] != 'primary' and params['event'] == 'revert' and not c.ha.do_revert():
                    process_node = False

        elif index < max_node:
            # Looking for a range of nodes
            if (index <= node_index) and (node_index <= max_node):
                process_node = True
        else:
            c.log.error("Invalid node range of %d to %d" % (index, max_node))

        if process_node:
            c.log.info("Node event on: {}".format(index))
            event_on_one_node(c, event_type, node, params)
    response['msg'] = "Node_event processed successfully"
    return json.dumps(response)


def server(c):
    # Find out the process ID
    pid = os.getpid()

    # Open up a file to write error and debug messages
    c.log.info("High availability server started with pid=%d" % pid)

    # Create an instance of the node manager
    nodeTable = NodeTable()

    # Create a UDS socket
    sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)

    # Bind the socket to the port
    sock.bind(sock_file)

    # Listen for incoming connections
    sock.listen(1)

    while server_running:
        try:
            # Wait for a connection
            connection, client_address = sock.accept()

            # Read a command from the client
            line = connection.recv(300)
            c.log.debug("Server got command %s" % line)
            cmd_list = line.rsplit(' ')
            cmd_name = cmd_list[0].rsplit('.', 1)[0]
            ret_msg = ''

            # Call the function that handles this command
            if cmd_name != 'clear_params':
                cmd_dict = {}
                i = 1
                while i < len(cmd_list):
                    if cmd_list[i] == '-i':
                        keyword = "index"
                    elif cmd_list[i] == '-mi':
                        keyword = "range"
                    elif cmd_list[i] == '-m':
                        keyword = "mode"
                    elif cmd_list[i] == '-c':
                        keyword = "command"
                    elif cmd_list[i] == '-e':
                        keyword = "event"
                    elif cmd_list[i] == '':
                        break
                    else:
                        keyword = c.ha.check_cloud_command(cmd_list[i])
                    value = cmd_list[i + 1]
                    i = i + 2
                    if keyword != 'Error':
                        cmd_dict[keyword] = value
                        c.log.info("Added keyword %s with value %s" % (keyword, value))

            if cmd_name == 'create_node':
                ret_msg = create_node(c, nodeTable, cmd_dict)
            elif cmd_name == 'set_params':
                ret_msg = set_params(c, nodeTable, cmd_dict)
            elif cmd_name == 'clear_params':
                ret_msg = clear_params(c, nodeTable, cmd_list)
            elif cmd_name == 'show_node':
                ret_msg = show_node(c, nodeTable, cmd_dict)
            elif cmd_name == 'delete_node':
                ret_msg = delete_node(c, nodeTable, cmd_dict)
            elif cmd_name == 'node_event':
                ret_msg = node_event(c, nodeTable, cmd_dict)
            elif cmd_name == 'stop':
                ret_msg = stop_server()
            elif cmd_name == 'ping':
                ret_msg = 'OK'
            else:
                ret_msg = "Unknown server command %s" % cmd_name
                c.log.error("Unknown server command %s" % cmd_name)

            connection.sendall(ret_msg)
        except socket.error as err:
            c.log.error("Server socket error %d" % err.errno)

        except Exception as e:
            c.log.exception("Server Exception: %s" % e)
            connection.sendall(e.message)

    # Clean up the connection
    c.log.info("Server exiting")
    connection.close()
    return 0


def start_server(c):
    global server_running

    print "Starting the high availability server"
    c.log.info("Starting the high availability server")
    server_running = True

    # Make sure the socket does not already exist
    try:
        os.unlink(sock_file)
    except OSError:
        if os.path.exists(sock_file):
            os_command = "rm %s" % sock_file
            os.system(os_command)

    p = Process(target=server, args=(c,))
    p.start()
    p.join()


def stop_server(c):
    global server_running

    print "Processing a stop_server command"
    c.log.info("Processing a stop_server command")
    server_running = False

    # Make sure the socket does not already exist
    try:
        os.unlink(sock_file)
    except OSError:
        if os.path.exists(sock_file):
            os_command = "rm %s" % sock_file
            os.system(os_command)
    return 'OK'


def main(argv):
    c = cloud('HA')

    parser = argparse.ArgumentParser(description="CSR HA API Server")
    parser.add_argument('start', nargs='?', const=True, help='start server', default=None)
    # parser.add_argument('stop', help='stop server', default=None)
    args = parser.parse_args()

    if args.start is not None:
        start_server(c)

    elif args.stop is not None:
        stop_server(c)
        return 0
    else:
        return 'ERR1'


if __name__ == '__main__':
    sys.exit(main(sys.argv))


#!/usr/bin/env python
from multiprocessing import Process
from csr_cloud.csr_cloud import csr_cloud as cloud
from os.path import expanduser

cert_file = "/etc/ssl/certs/ca-bundle.trust.crt"


def handler(node, event_type):
    c = cloud("HA")
    c.ha.set_event_logger(node, event_type)
    try:

        c.ha.event_logger.info("Event type is %s" % event_type)

        # Verify the node has been sufficiently configured
        rc = c.ha.verify_node(node, event_type)
        if 'OK' != rc:
            c.ha.event_logger.info("Event processing aborted")
            return

        c.ha.event_logger.info("CSR HA: %s event for node" %event_type)

        route_table = c.ha.get_route_table(node, event_type)
        if not route_table:
            # since there are no route tables in gcp cloud, we expect a None for RT
            c.ha.event_logger.info("Route table not found.")

        c.ha.event_logger.info("CSR HA: Set route table for %s" % event_type)
        response = c.ha.set_route_table(node, event_type, route_table)

    except Exception as e:
        c.ha.event_logger.exception("Event Handler Exception: %s" % e)


def handle_event(node, event_type):
    c = cloud("HA")
#    print "Starting an event handler process"
    try:
        p = Process(target=handler, args=(node, event_type))
        p.start()
        p.join()
    except Exception as e:
        c.log.exception("HA Server Exception: %s" % e)




from distutils.core import setup
from setuptools.command.install import install
from subprocess import check_call
import os


class PostInstallCommand(install):
    """Post-installation for installation mode."""

    def run(self):
        # note: pip install suppresses all user stdout/stderr output unless -v/--verbose option is specified. 
        print "We are running in the postInstallCommand"
        cwd = os.path.dirname(os.path.realpath(__file__))
        check_call("bash %s/ha_tools.sh" % cwd, shell=True)
        install.run(self)
        print "NOTE: 'source ~/.bashrc' is necessary for HA commands to be accessible."


project_name = 'csr_ha'
project_ver = '1.0.1'

setup(
    name=project_name,
    packages=[project_name],  # this must be the same as the name above
    version=project_ver,
    description='High availability of CSR 1000v routers in cloud',
    author='Richard Williams',
    author_email='richawil@cisco.com',
    scripts=['csr_ha/client_api/node_event.py',
             'csr_ha/client_api/clear_params.py',
             'csr_ha/client_api/revert_nodes.sh',
             'csr_ha/client_api/create_node.py',
             'csr_ha/client_api/set_params.py',
             'csr_ha/client_api/delete_node.py',
             'csr_ha/client_api/ha_api.py',
             'csr_ha/client_api/show_node.py',
             'ha_tools.sh',
             'csr_ha/client_api/py_caller.py',
             'csr_ha/client_api/node_event',
             'csr_ha/client_api/clear_params',
             'csr_ha/client_api/create_node',
             'csr_ha/client_api/set_params',
             'csr_ha/client_api/delete_node',
             'csr_ha/client_api/show_node'
            ],
    # use the URL to the github repo
    url='https://github4-chn.cisco.com/csr1000v-cloud/' + project_name,
    download_url='https://github4-chn.cisco.com/csr1000v-cloud/' + project_name + '/archive/' + \
        project_ver + '.tar.gz',
    keywords=['cisco', 'ha', 'high availability', 'csr1000v', 'csr', 'guestshell'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],
    license="MIT",
    include_package_data=True,
    install_requires=['ipaddress'],
    cmdclass={
        'install': PostInstallCommand,
    },
)
